Cluster Project branch, master, updated. cluster-2.99.01-13-g9b78342

rpeterso@sourceware.org rpeterso@sourceware.org
Mon May 19 03:50:00 GMT 2008


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Cluster Project".

http://sources.redhat.com/git/gitweb.cgi?p=cluster.git;a=commitdiff;h=9b7834238366e6dc27143b424d8d8418789beee1

The branch, master has been updated
       via  9b7834238366e6dc27143b424d8d8418789beee1 (commit)
      from  3a8f3538e1da5794e08ceb825a4b2b77e7052f6d (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit 9b7834238366e6dc27143b424d8d8418789beee1
Author: Bob Peterson <rpeterso@redhat.com>
Date:   Sun May 18 22:47:35 2008 -0500

    Replace put_inode with drop_inode

-----------------------------------------------------------------------

Summary of changes:
 gfs-kernel/src/gfs/ops_super.c |   11 ++++-------
 1 files changed, 4 insertions(+), 7 deletions(-)

diff --git a/gfs-kernel/src/gfs/ops_super.c b/gfs-kernel/src/gfs/ops_super.c
index 1ee2d93..cfc8faf 100644
--- a/gfs-kernel/src/gfs/ops_super.c
+++ b/gfs-kernel/src/gfs/ops_super.c
@@ -62,7 +62,7 @@ gfs_write_inode(struct inode *inode, int sync)
 }
 
 /**
  * gfs_put_inode - put an inode
  * @inode: The inode
  *
  * If i_nlink is zero, any dirty data for the inode is thrown away.
@@ -70,11 +70,8 @@ gfs_write_inode(struct inode *inode, int sync)
  * data.  So, sync it out.
  */
 
-// XXX FIX ME!
-
-#if 0
 static void
-gfs_put_inode(struct inode *inode)
+gfs_drop_inode(struct inode *inode)
 {
 	struct gfs_sbd *sdp = get_v2sdp(inode->i_sb);
 	struct gfs_inode *ip = get_v2ip(inode);
@@ -86,8 +83,8 @@ gfs_put_inode(struct inode *inode)
 	    S_ISREG(inode->i_mode) &&
 	    !sdp->sd_args.ar_localcaching)
 		gfs_sync_page_i(inode, DIO_START | DIO_WAIT);
+	generic_drop_inode(inode);
 }
-#endif
 
 /**
  * gfs_put_super - Unmount the filesystem
@@ -459,7 +456,7 @@ gfs_show_options(struct seq_file *s, struct vfsmount *mnt)
 
 struct super_operations gfs_super_ops = {
 	.write_inode = gfs_write_inode,
-	// XXX FIX ME .put_inode = gfs_put_inode,
+	.drop_inode = gfs_drop_inode,
 	.put_super = gfs_put_super,
 	.write_super = gfs_write_super,
 	.write_super_lockfs = gfs_write_super_lockfs,
@@ -62,7 +62,7 @@ gfs_write_inode(struct inode *inode, int sync)
 
 /**
- * gfs_put_inode - put an inode
+ * gfs_drop_inode - put an inode
  * @inode: The inode
  *


hooks/post-receive
--
Cluster Project



More information about the Cluster-cvs mailing list